{% extends "base.html" %}

{% block title %}Create page: {{ slug }}{% endblock %}

{% block content %}
<h1>Create page: {{ slug }}</h1>

<form action="" method="POST">
  <p>
    <input type="hidden" name="csrftoken" value="{{ csrftoken() }}">
    <textarea style="width: 90%; height: 20em" name="content"></textarea>
  </p>
  <p><input type="submit" value="Save"></p>
</form>

{% endblock %}
